@@ -1,3 +1,3 @@
 def perc(x, y, d=2): 
 	calc = round(((1.0 * x/y * 100), d)
-	return calc
\ No newline at end of file
+	return(calc)
